
//var SimpleMarkdown = require("simple-markdown");
var SimpleMarkdown = require("./index.js");

var modifiedTextRule = Object.assign({}, SimpleMarkdown.defaultRules.text, {
    match: function(source) {
        return /^[\s\S]+?(?=[^0-9A-Za-z\s\u00c0-\uffff]|\n\n| {2,}\n|\w+[:\.]\S|$)/.exec(source);
    }
});

var rawUrlRule = {
    // Specify the order in which this rule is to be run
    order: SimpleMarkdown.defaultRules.url.order - 0.5,

    // First we check whether a string matches
    match: function(source) {
        return /^([\w\-~/?#!$&'*+,;=%]+\.[\w\-~/?#!$&'*+,;=%\.]+)/.exec(source);
    },

    // Then parse this string into a syntax node
    parse: function(capture, parse, state) {
        return {
            type: "link",
            content: [{
                type: "text",
                content: capture[1],
            }],
            target: "http://" + capture[1],
        };
    }
};

var rules = Object.assign({}, SimpleMarkdown.defaultRules, {
    rawUrl: rawUrlRule,
    text: modifiedTextRule,
});

var rawBuiltParser = SimpleMarkdown.parserFor(rules);
var blockParse = function(source) {
    var blockSource = source + "\n\n";
    return rawBuiltParser(blockSource, {inline: false});
};
// You probably only need one of these: choose depending on
// whether you want react nodes or an html string:
var reactOutput = SimpleMarkdown.reactFor(SimpleMarkdown.ruleOutput(rules, 'react'));
var htmlOutput = SimpleMarkdown.htmlFor(SimpleMarkdown.ruleOutput(rules, 'html'));

console.log(htmlOutput(blockParse("Here's some text with a link to google.com and www.example.com")));

module.exports = {
    blockParse: blockParse,
    reactOutput: reactOutput,
    htmlOutput: htmlOutput,
};
